from setuptools import setup

setup(
    name="privathon",
    version="0.0.1",
    description = "private scoped python",
    py_modules=["privation"],
    author='du7ec',
    author_email='dutec6834@gmail.com',
    keywords=["privathion", "private", "scoped", "python"]
)
